--lua 公用函数
--参数说明: 写日志、调试信息等使用
--   参数数量:1
--   参数类型:日志内容
    function api_writeLog( ... ) 
		return WriteLog(...);
	end
--参数说明:  发送按键
--  参数数量:1
--  参数类型:数值 1-255 为ascii码
    function api_sendKey( AintAscii )	
		return sendKey( AintAscii );
	end
--参数说明:  发送按键
--  参数数量:2
--  参数类型:数值 1-255 为ascii码, 参数2，1为按下，0为弹起
    function api_sendKeyEx( AintAscii, AintIsDown )	
		return sendKeyEx( AintAscii, AintIsDown );
	end
--参数说明:  按下按键
--  参数数量:1
--  参数类型:数值 1-255 为ascii码,
    function api_SIKeyDown( AintAscii)	
		return SIKeyDown( AintAscii );
	end
--参数说明:  弹起按键
--  参数数量:1
--  参数类型:数值 1-255 为ascii码
    function api_SIKeyUp( AintAscii)	
		return SIKeyUp( AintAscii );
	end
--参数说明:  发送按键
--  参数数量:1
--  参数类型:英文字母字母，如果有多个取第一个
    function api_sendChar( AintChar )	
		return sendChar( AintChar );
	end
--参数说明:  发送按键
--  参数数量:1
--  参数类型:字符串，支持中英文
    function api_sendString( AstrString)	
		return sendString(AstrString);
	end
--参数说明:  暂停函数。同sleep
-- 参数数量:1
--  参数类型:数值，sleep的时间，以毫秒为单位 1000为1秒
    function api_LuaSleep( AintTime ) 	
		return LuaSleep( AintTime );
	end
--参数说明:  模拟鼠标点击
--  参数数量:2
--  参数类型:数值，1:x，2:y.相对FLASH窗口的X、Y。

    function api_sendMouseClick( AintX, AintY ) 
		return SendMouseClick( AintX, AintY );
	end
-- 参数说明:  在屏幕上找图片 找到后返回图片的左上角地址
-- 参数数量: 1
--  参数类型: 要查找的图片的相对路径。相对于程序目录。
--  返回值:3个，1:表示是否找到图片(1找到、0没找到),2:找到后图片所在X地址,3:找到后图片所在Y地址
    function api_findBmp( AstrFilePath ) 	
		return FindBmp( AstrFilePath );
	end
--参数说明:  在屏幕上找图片 并点击图片。
--  参数数量: 3
--    参数类型: 1：要查找的图片的相对路径。相对于程序目录。
--              2：点击的位置X相对查找的图片
--              3：点击的位置y相对查找的图片
--    返回值:3个，1:表示是否找到图片(1找到、0没找到),2:找到后图片所在X地址,3:找到后图片所在Y地址
    function api_checkBmp( AstrFilePath, AintX, AintY )	
		return CheckBmp( AstrFilePath, AintX, AintY );
	end
--参数说明:  多点找图.通过图片特码找图片的位置
--    参数数量: 3
--    参数类型: 1：开始查找的X点
--              2：开始查找的Y点
--              3：查找的X范围 
--              4：查找的Y范围
--              5：要找的第一个点的颜色值
--              6：相对与第一个点之后点的颜色|X|Y信息
--    返回值:3个，1:表示是否找到图片(1找到、0没找到),2:找到后图片所在X地址,3:找到后图片所在Y地址
    function api_findMultiColor( AintBeginX, AintBeginY, AintMaxX, AintMaxY, AclrFirst, AstrParamter )	
		return FindMultiColor( AintBeginX, AintBeginY, AintMaxX, AintMaxY, AclrFirst, AstrParamter );
	end
--参数说明:  发送数据包 数据包为16进制码的字符串
-- 参数数量: 1
--  参数类型: 1：数据包

    function api_sendData(AstrBinData)	
		return SendData( AstrBinData );
	end	

-- 参数说明:  设置血量
--  参数数量:1
--    参数类型:数值    
    function api_setHP( AintHP )
		return SetHP(  AintHP );
	end
-- 参数说明:  设置魔法量
--   参数数量:1
--   参数类型:数值    
    function api_setMP( AintMP ) 
		return SetMP( AintMP );
	end
-- 参数说明: 获取屏幕上点的颜色
-- 参数数量:2
-- 参数类型:数值,1:X, 2 : Y
--   返回:1是颜色数值(integer类型)    
    
    function api_getPixColor( AintX, AintY ) 
		return GetPicColor( AintX, AintY );
	end

--  参数说明: 颜色转RBG
--  参数数量:1
--    参数类型:数值型，为TColor类型，或整型
--    返回:R,G,B
    function api_colorToRGB( AintClr )
		return ColorToRGB( AintClr );
	end

--  参数说明: 获取屏幕窗口大小。
--    参数数量:0
--    参数类型:
--    返回:width, high
    function api_getWindowRect() 
		return GetWindowRect();
	end
--    参数说明: 设置游戏快键包状态。
--    参数数量:多个
--    参数类型: 0,1
--    返回:无

   function api_setPkgState( ... ) 
		return SetPkgState(...);
   end

--   参数说明:  是否还有药水。包括大药小药
--   参数数量:0
--    参数类型:
--    返回:1表示有，0表示没有
    function api_checkHaveHP( )
		return CheckHaveHP();
	end
--    参数说明:  保存变量到程序中
--      参数数量:2
--      参数类型: 1:变量序号，2:值(字符串型)
--      返回:无
    
    function api_setValue( AintIdx, AstrString ) 
		return SetValue(AintIdx, AstrString );
	end
--    参数说明:  保存变量到程序中
--      参数数量:1
--      参数类型: 1:变量序号
--      返回:返回值 （字符串型）    
    function api_getValue( AintIdx ) 
		return GetValue( AintIdx );
	end
--参数说明:  导步进程运行时。用与检测，是否终止运行
--    参数数量:1
--    参数类型: 1:线程序号
--    返回:1正常，0终止
    function api_checkThread( AintIdx )
		return  CheckThread( AintIdx );
	end
--参数说明:  获取图片中的文字
--    参数数量:8
--    参数类型: 1:开始坐标X，开始坐标Y，目标坐标X，目标坐标Y，红R，绿G，蓝B，最大误差值Range,字宽
--    返回:字符串
    function api_getImageText(AintBeginX, AintBeginY, AintMaxX, AintMaxY, AintR,AintG,AintB, AintRange ) 
		return  GetImageText( AintBeginX, AintBeginY, AintMaxX, AintMaxY, AintR,AintG,AintB, AintRange, 6);
	end
--参数说明:  打开IE
--     参数数量:1
--    参数类型: 1:URL
	function api_openYYRoom( AstrYYRoomID ) 
		return  OpenYYRoom(AstrYYRoomID);
	end
--参数说明:  返回网页运行时间
-- 参数数量:0
-- 返回:数字（毫秒）
   function api_getRunTime()
		return GetRunTime();
   end 
--运行辅助
   function api_RunApp()
		return RunApp();
   end 
--停止辅助
   function api_StopApp()
		return StopApp();
   end 