require "global";
require "local";
require "Nz_wpe";



i=os.time() - 15;
j=os.time() - 60*60*8 + 5 ;
k=os.time() - 50;

while api_checkThread(2)  do


	intW, intH = GetWindowRect(); --获取窗体的高和宽

	if ((os.time()-i) >= 20) then
		sendMouseClick( intW  - 1, 1); --发送点击事件
		api_LuaSleep(1000);

--		sendMouseClick( intW  - 1, 1); --发送点击事件
--		api_LuaSleep(1000);

		sendMouseClick( intW  - 1, intH - 1); --发送点击事件
		api_LuaSleep(1000);

--		sendMouseClick( intW  - 1, intH - 1); --发送点击事件
--		api_LuaSleep(1000);

		sendMouseClick( 1, intH - 1 ); --发送点击事件
		api_LuaSleep(1000);

--		sendMouseClick( 1, intH - 1); --发送点击事件
--		api_LuaSleep(1000);

--		sendMouseClick( 1, 1 ); --发送点击事件
--		api_LuaSleep(1000);

		sendMouseClick( 1, 1 ); --发送点击事件
--		api_sendKey( '90' );--z

		i=os.time();

	end

--	n = api_checkHaveHP( );
--	WriteLog(n);
--	if n == 1 then
--		taiyangshui();
--		api_LuaSleep(5000);
--		while n < 21 and api_checkThread(2) do
--			taiyangshui();
--			api_LuaSleep(1000);
--			n = n + 1;
--		end
--	end



--	if ((os.time()-k) >= 1) then
--		api_sendKey( '81' );--q
--		k=os.time();
--	end




--	if ((os.time()-j) >= 60*60*8) then
--		yjxzb();
--		j=os.time();
--	end


--	if ((os.time()-k) >= 60) then
--		yjcs();
--		k=os.time();
--	end
	api_LuaSleep(3000);
--	WriteLog('time:', os.time() );
end
